configurationtools.write_abjad_user_config_file
===============================================

.. autofunction:: abjad.tools.configurationtools.write_abjad_user_config_file.write_abjad_user_config_file
